Module testutils

Module testutils 

Common parser testing utilities

Functions

test_buffer_windows_output_no_res
Run the given parser with many different initial buffer sizes, calling check on the outputs each time, which must panic to cause a test failure
test_buffer_windows_outputs
Run the given parser with many different initial buffer sizes, calling check on the outputs each time
test_buffer_windows_res
Run the given parser with many different initial buffer sizes, calling check on the results each time