test_buffer_windows_res

Function test_buffer_windows_res 

pub fn test_buffer_windows_res<B, I, F, E>(
    bfmt: B,
    input: I,
    check: F,
) -> Result<(), E>
where B: Clone + ByteParser, I: AsRef<[u8]>, F: Fn(Result<B::Output, E>) -> Result<(), E>, E: From<B::Error> + From<Error>,
Run the given parser with many different initial buffer sizes, calling check on the results each time

This test function helps catch bounds errors in Parser / BufferManager implementations