Common parser testing utilities
Functions
- test_
buffer_ windows_ output_ no_ res - Run the given parser with many different initial buffer sizes, calling
checkon the outputs each time, which must panic to cause a test failure - test_
buffer_ windows_ outputs - Run the given parser with many different initial buffer sizes, calling
checkon the outputs each time - test_
buffer_ windows_ res - Run the given parser with many different initial buffer sizes, calling
checkon the results each time