pub fn test_buffer_windows_res<B, I, F, E>(
bfmt: B,
input: I,
check: F,
) -> Result<(), E>Expand description
Run the given parser with many different initial buffer sizes, calling check on the results each time
This test function helps catch bounds errors in Parser / BufferManager implementations